import * as React from 'react';
import { IBarChartProps } from './BarChart.props';
import './BarChart.scss';
export declare class BarChartContent extends React.PureComponent<IBarChartProps, any> {
    private tooltip;
    private selected;
    constructor(props: IBarChartProps);
    componentWillReceiveProps(newProps: any): void;
    componentDidMount(): void;
    componentDidUpdate(): void;
    /**
     * Binds appropriate data to every bar element in dom using d3 data function.
     */
    private bindData();
    render(): JSX.Element;
    /**
     * Renders bars with appropriate width and height based on data set. On every bar appropriate event listeners
     * are set.
     */
    private renderBars();
    /**
     * When bar is clicked set that bar reference as active and set css class to it
     * so it will be colored into different color.
     */
    private handleOnClick(element);
    /**
     * This function is invoked when container element for axis is placed into DOM.
     * It creates x axis based on given axis generator.
     */
    private renderXAxis(element);
    /**
    * This function is invoked when container element for axis is placed into DOM.
    * It creates x axis based on given axis generator.
    */
    private renderYAxis(element);
    /**
     * Returns y axis generator that scales accross given height with domain of maximum data frequency values.
     */
    private generateY();
    /**
     * Returns x axis generator that scales accross given width with domain of all data elements.
     */
    private generateX();
    /**
     * Returns format for axis that is then passed into format function.
     * If function recieves null value default formatting will be applied.
     * If type of data is date object then time format is applied, otherwise regular format
     * function is used.
     */
    private formatAxisLabels();
    /**
     * Event which is called when user points mouse to bar.
     * Dimensions of element are calculated and passed to tooltip component for
     * positioning on top of bar.
     */
    private onMouseOver(element);
    /**
     * Calculates available space for labels.
     * If space is too narrow labels are rotated by 45 degrees.
     */
    private calculateAvailableSpace();
}
