import * as React from 'react';
import { ILineChartProps, ILineChartData } from './LineChart.props';
import './LineChart.scss';
export declare class LineChart extends React.PureComponent<ILineChartProps, any> {
    static defaultProps: {
        width: number;
        height: number;
        xAxisTicks: number;
        yAxisTicks: number;
        yAxisDomain: number[];
        xAxisFormat: () => any;
        yAxisFormat: (d: number) => number;
        colorPallette: ReadonlyArray<string>;
        showLegend: boolean;
        tooltipText: (d: ILineChartData) => number;
    };
    private containerRef;
    constructor(props: ILineChartProps);
    render(): JSX.Element;
    /**
     * Initializes component. On first render only main container is rendered and based on his
     * width and height content inside it is rendered.
     */
    private init(element);
    /**
     * When resize sensor detect change in size of parent container calculates new dimensions
     * for chart content and render chart content based on new dimensions.
     */
    private onResize();
    /**
     * When component updates reset legend and lines to be shown.
     */
    componentDidUpdate(): void;
    /**
     * When component is unmounting detach resize sensor from main container.
     */
    componentWillUnmount(): void;
    /**
     * Renders legend based on given dataset. Legend is rendered as standard html elements.
     */
    private renderLegend();
    /**
     * When legend item is clicked this function gets called which show or hide
     * line series based on class of clicked legend item.
     */
    private showHideSeries(element);
}
