import * as React from 'react';
import { ILineChartProps } from './LineChart.props';
export declare class LineChartContent extends React.PureComponent<ILineChartProps, any> {
    private x;
    private y;
    private bisect;
    private circleData;
    constructor(props: ILineChartProps);
    /**
     * When component receives new props set state based on new props.
     */
    componentWillReceiveProps(newProps: ILineChartProps): void;
    /**
     * When component is mounted calculate space for labels and bind events and data
     * to circles which are used for showing tooltips.
     */
    componentDidMount(): void;
    /**
     * When component is updated calculate space for labels and bind events and data
     * to circles which are used for showing tooltips.
     */
    componentDidUpdate(): void;
    /**
     * Binds on mouse over event to circles and binds data to it so when mouse is hovered over
     * given circle tooltip with given information about that chart point can be displayed.
     */
    private setEventsAndBindData();
    render(): JSX.Element;
    /**
     * Color generator which is constructed based on given array of colors and returns
     * appropriate color from given array for given string.
     */
    private createColorPallette;
    /**
     * Draws chart lines and given transparent circles that are used for displaying tooltips based
     * on transformed data which does not containe null values.
     */
    private drawSeries();
    /**
     * Algorithm that finds null values for y-axis in given datasets and returns new arrays
     * without null values in between for charting.
     */
    private normalizeData();
    /**
     * When mouse is moved over a given point on chart calculate dimensions,
     * get data that is bound to that circle and call props function that formats
     * tooltip text.
     */
    private onMouseOver();
    /**
     * Renders x axis inside given element. This function gets called when
     * container for x axis gets mounted into DOM.
     */
    private renderXAxis(element);
    /**
     * Renders y axis inside given element. This function gets called when
     * container for y axis gets mounted into DOM.
     */
    private renderYAxis(element);
    /**
     * Creates x-axis generator based on given domain and range. Domain of given x-axis generator
     * is in range of minimum value of x argument of all given datasets and maximum value of y argument
     * of all given datasets.
     */
    private generateX();
    private getMinMaxFromSeries();
    /**
     * Creates y-axis generator based on given domain and range.
     */
    private generateY();
    /**
     * Creates line generator based on given dataset and x and y axis generators.
     */
    private renderLine(data);
    /**
     * Returns format function or null value if no format function is specified which is then used
     * in d3s function for formatting axis ticks.
     */
    private formatAxisLabels();
    /**
     * Calculates available space for labels.
     * If space is too narrow labels are rotated by 45 degrees.
     */
    private calculateAvailableSpace();
}
