import * as React from 'react';
import { ITooltipProps } from '../Tooltip/Tooltip.props';
import { IPoint } from '../../utilities/positioning';
export interface IQuickGrid {
    scrollToRow(index: number): void;
    updateColumnWidth(columnIndex: number, getWidth: (oldWidth: number) => number): void;
    recomputeGridSize(): void;
}
export declare enum SortDirection {
    Ascending = 0,
    Descending = 1,
}
export interface IGroupBy {
    column: string;
    sortDirection: SortDirection;
}
export interface IQuickGridProps {
    rows: Array<any>;
    columns: Array<GridColumn>;
    groupBy?: Array<string | IGroupBy>;
    gridClassName?: string;
    headerClassName?: string;
    rowHeight?: number | ((info: {
        index: number;
    }) => number);
    overscanRowCount?: number;
    displayGroupContainer?: boolean;
    sortColumn?: string;
    sortDirection?: SortDirection;
    gridActions?: QuickGridActions;
    columnSummaries?: any;
    actionsTooltip?: string;
    tooltipsEnabled?: boolean;
    hasCustomRowSelector?: boolean;
    hasStaticColumns?: boolean;
    columnHeadersVisible?: boolean;
    isRowSelectable?: boolean;
    delayMs?: number;
    filterString?: string;
    showAutoFilterRow?: boolean;
    filterPlaceholderText?: string;
    hideGroupExpandButton?: boolean;
    hasColumnPicker?: boolean;
    visibleColumns?: Array<GridColumn>;
    columnPickerIconClassName?: string;
    onSelectedRowChanged?: (selectedRowIndex: number, rowData: any) => void;
    onRowDoubleClicked?: (row: any) => void;
    customRowSorter?: (sortBy, sortDirection) => void;
    customCellRenderer?: (args: ICustomCellRendererArgs) => React.ReactNode;
    onGroupByChanged?: (groupBy: Array<IGroupBy>) => void;
    groupRowFormat?: (rowData: any, columnName?: string) => React.ReactNode;
    onGroupBySort?: (sortBy: string, sortDirection: SortDirection) => void;
    onColumnSelectionChanged?: (picked: Array<GridColumn>) => void;
}
export interface ICustomCellRendererArgs {
    columnIndex: number;
    key: any;
    rowIndex: number;
    style: any;
    onMouseEnter: any;
    onMouseClick: any;
    isSelectedRow: boolean;
    rowActionsRender: (rowIndex: number, rowData: any, isSelectedRow: boolean) => React.ReactNode;
}
export interface IQuickGridState {
    sortColumn?: string;
    sortDirection?: SortDirection;
    groupBy?: Array<IGroupBy>;
    collapsedRows: Array<string>;
    columnWidths: Array<number>;
    selectedRowIndex?: number;
    columnsToDisplay: Array<GridColumn>;
    hasVerticalScroll: boolean;
    scrolledRow: number;
    columnFilters?: Array<FiltersData>;
    headerContextMenuPointTarget?: IPoint;
    isColumnPickerOpen: boolean;
    pickedColumns?: Array<GridColumn>;
}
export interface GroupRow {
    type: 'GroupRow';
    columnGroupName: string;
    name: string;
    displayName?: string;
    depth: number;
    groupKey: string;
    isExpanded: boolean;
}
export declare enum DataTypeEnum {
    Number = 0,
    String = 1,
    Date = 2,
    Boolean = 3,
}
export declare enum BoolFormatTypeEnum {
    /**
     * No icons, only text
     */
    TextOnly = 0,
    /**
     * Checkmark for true, nothing for false
     */
    CheckmarkOnly = 1,
    /**
     * Checkmark for true, cross for false
     */
    CheckmarkAndCross = 2,
}
export interface GridColumn {
    headerText: string;
    valueMember: string;
    getCellValue?: (rowData) => any;
    dataType?: DataTypeEnum;
    boolFormatType?: BoolFormatTypeEnum;
    isSortable?: boolean;
    isGroupable?: boolean;
    sortByValueGetter?: (cellData, sortDirection: SortDirection) => any;
    width: number;
    minWidth?: number | (() => number);
    fixedWidth?: boolean;
    dataMember?: string;
    cellFormatter?: (cellData, rowData) => any;
    cellClassName?: string;
    headerClassName?: string;
    headerTooltip?: string;
}
export declare const defaultMinColumnWidth = 50;
export declare function getColumnMinWidth(col: GridColumn): number;
export declare const lowercasedColumnPrefix = "lowercase_";
export interface QuickGridActions {
    /**
     * the global action items, these will be shown when actionsBehavior equals to ShowAsFirstColumn.
     * If ShowOnRowHover behaviour is used, then they will be shown only if OnGetSingleRowActions does not return a value
     */
    actionItems: Array<ActionItem>;
    /**
     * Determined where the actions will be shown
     */
    actionsBehaviour?: QuickGridActionsBehaviourEnum;
    /**
     * This icon will be used for the dropdown when actionsBehavior equals to ShowAsFirstColumn
     */
    actionIconName: string;
    /**
     * used in ShowOnRowHover behaviour to specify actions per row
     */
    onGetSingleRowContextActions?: (rowData) => Array<ActionItem> | ContextActionsObject;
    onActionSelected: (commandName: string, parameters, rowData) => void;
    hideDropdownActionIcons?: boolean;
}
export interface ContextActionsObject {
    actions: Array<ActionItem>;
    dropdownIconName?: string;
    dropdownCustomRenderer?: (rowIndex: number, actions: Array<ActionItem>, onMenuToggle: (opened: boolean) => void, onActionClicked: (rowIndex: number, action: ActionItem) => void) => JSX.Element;
}
export declare function isContextActionsObject(arg: any): arg is ContextActionsObject;
export declare enum QuickGridActionsBehaviourEnum {
    ShowAsFirstColumn = 0,
    ShowOnRowHover = 1,
}
export interface ActionItem {
    name: string;
    commandName: string;
    iconName?: string;
    parameters?: any;
    tooltip?: ITooltipProps;
    showInDropdown?: boolean;
    isMultiSelectAction?: boolean;
    buttonClass?: string;
}
export interface FiltersProps {
    headerColumns: Array<GridColumn>;
    width: number;
    columnWidths: Array<number>;
    scrollLeft: number;
    allColumns: Array<GridColumn>;
    columnFilters: Array<FiltersData>;
    groupBy: IGroupBy[];
    hasActionColumn: boolean;
    placeholderText?: string;
    addColumnFilter: (filterData: FiltersData) => void;
    removeColumnFilter: (filterData: FiltersData) => void;
}
export interface FiltersData {
    columnIndex: number;
    filterValue: string;
}
export interface ColumnFilterProps {
    columnIndex: number;
    filterValue: string;
    isNotEmpty: boolean;
    placeholderText?: string;
    addColumnFilter: (filterData: FiltersData) => void;
    removeColumnFilter: (filterData: FiltersData) => void;
}
