import { DirectionalHint } from '../../utilities/DirectionalHint';
import { TreeLookups } from './TreeItemOperators';
import { IHoverOverBtn } from '../Treeview';
export declare enum FilterSelectionEnum {
    All = 0,
    None = 1,
    Selected = 2,
}
export interface IFilterSelection {
    type: FilterSelectionEnum;
    selectedIDs: Array<string>;
}
export declare enum CheckStatus {
    Checked = 0,
    NotChecked = 1,
    ChildChecked = 2,
}
export interface ITreeFilterProps {
    filterId: string;
    items: Array<TreeItem>;
    title?: string;
    iconName?: string;
    disabled?: boolean;
    filterSelection?: IFilterSelection;
    hasSearch?: boolean;
    isSingleSelect?: boolean;
    isGroupSelectableOnSingleSelect?: boolean;
    shouldGroupExpandOnDoubleClick?: boolean;
    enableRecursiveSelection?: boolean;
    itemsAreFlatList?: boolean;
    onValuesSelected?: (filterId: string, filterSelection: IFilterSelection) => void;
    defaultSelection?: FilterSelectionEnum;
    rowHeight?: number;
    hasTitleBorder?: boolean;
    showButtons?: boolean;
    onSave?: (filterId: string, filterSelection: IFilterSelection) => void;
    width?: number;
    height?: number;
    minWidth?: number;
    minHeight?: number;
    maxWidth?: number;
    maxHeight?: number;
    showSelectAll?: boolean;
    directionalHint?: DirectionalHint;
    clearSearchOnClose?: boolean;
    emptySelectionText?: string;
    showStatusBar?: boolean;
    enabledResizeHandles?: {
        top: boolean;
        right: boolean;
        bottom: boolean;
        left: boolean;
        topRight: boolean;
        bottomRight: boolean;
        bottomLeft: boolean;
        topLeft: boolean;
    };
    onItemExpand?: (treeItem?: TreeItem, lookupTableGetter?: () => TreeLookups) => void;
    onCalloutClose?(): void;
    validated?: boolean;
    validationErrorMessage?: string;
    isReady?: boolean;
    showResetButton?: boolean;
    calloutClassName?: string;
}
export declare const defaultTreeFilterProps: Partial<ITreeFilterProps>;
export interface ITreeFilterState {
    isOpen: boolean;
    isReady: boolean;
    isDefaultSelected: boolean;
    selectionText: string;
    query: string;
    selection: IFilterSelection;
    titleText: string;
}
export interface TreeItem {
    id: string;
    value: string;
    expanded?: boolean;
    children?: Array<TreeItem>;
    className?: string;
    iconName?: string;
    iconClassName?: string;
    hasChildren?: boolean;
    hoverOverBtn?: Array<IHoverOverBtn>;
    renderElement?: (itemKey: string, style: any) => JSX.Element;
    iconTooltipContent?: string;
    asyncChildrenLoadInProgress?: boolean;
    /**
     * Used to show a tooltip for item in callout
     * Implemented only for Single Select TreeFilter
     */
    itemTooltipInfo?: {
        title?: string;
        content: string | JSX.Element;
        directionalHint?: DirectionalHint;
        className?: string;
    };
}
