import { TreeItem } from './treeFilter.Props';
export interface TreeBranch {
    id: string;
    depth: number;
}
export interface LeafsAndBranches {
    Leafs: Array<string>;
    Branches: Array<TreeBranch>;
}
export interface CheckResult {
    checked: Array<string>;
    partially: Array<string>;
}
export interface ILookupTable {
    [id: string]: TreeItem;
}
export interface TreeLookups {
    parentLookup: ILookupTable;
    itemLookup: ILookupTable;
}
/**
 * Check if current tree item has children by checking if its children property
 * is not null and its length is greater than 0.
 * @param item Current tree item.
 */
export declare const itemHasChildren: (item: TreeItem) => boolean;
export declare class ItemOperator {
    static getLookupTableAndParentLookup: (items: TreeItem[]) => TreeLookups;
    /**
     * Returns ids of all items in tree structure in single array.
     */
    static getAllItemIds: (entryItems: TreeItem[]) => ReadonlyArray<any>;
    /**
     * Returns ids of all children that are children of current item or any
     * of its child recursive.
     */
    static getAllChildrenIds: (currentItem: TreeItem) => string[];
    static getAllLeafsAndBranches: (currentItem: TreeItem, originalItem: TreeItem) => LeafsAndBranches;
    /**
     * Filters given array of tree items based on given search string.
     * Values and search query will be converted to lowercase before so this
     * search is case insensitive.
     */
    static filterItems: (items: TreeItem[], query: string) => TreeItem[];
}
